@@ -40,29 +40,33 @@ CPANPLUS::Selfupdate
 
     my $Modules = {
         dependencies => {
-            'File::Fetch'               => '0.08', # win32 ftp support
+            'File::Fetch'               => '0.15_02', # lynx & 404 handling
             'File::Spec'                => '0.82',
             'IPC::Cmd'                  => '0.36', # 5.6.2 compat: 2-arg open
             'Locale::Maketext::Simple'  => '0.01',
             'Log::Message'              => '0.01',
             'Module::Load'              => '0.10',
-            'Module::Load::Conditional' => '0.16', # Better parsing: #23995
-            'version'                   => '0.70', # needed for M::L::C
+            'Module::Load::Conditional' => '0.38', # returns dir for loaded
+                                                   # modules
+            'version'                   => '0.73', # needed for M::L::C
                                                    # addresses #24630 and 
                                                    # #24675
+                                                   # Address ~0 overflow issue
             'Params::Check'             => '0.22',
             'Package::Constants'        => '0.01',
-            'Term::UI'                  => '0.05',
+            'Term::UI'                  => '0.18', # option parsing
             'Test::Harness'             => '2.62', # due to bug #19505
                                                    # only 2.58 and 2.60 are bad
             'Test::More'                => '0.47', # to run our tests
             'Archive::Extract'          => '0.16', # ./Dir bug fix
             'Archive::Tar'              => '1.23',
             'IO::Zlib'                  => '1.04', # needed for Archive::Tar
-            'Object::Accessor'          => '0.32', # overloaded stringification
-            'Module::CoreList'          => '2.09',
+            'Object::Accessor'          => '0.34', # mk_aliases support
+            'Module::CoreList'          => '2.22', # deprecated core modules
             'Module::Pluggable'         => '2.4',
             'Module::Loaded'            => '0.01',
+            'Parse::CPAN::Meta'         => '0.02', # config_requires support
+            'ExtUtils::Install'         => '1.42', # uninstall outside @INC
         },
     
         features => {
@@ -75,18 +79,13 @@ CPANPLUS::Selfupdate
                     my $cb = shift;
                     $cb->configure_object->get_conf('prefer_makefile') 
                         ? { }
-                        : { 'CPANPLUS::Dist::Build' => '0.04'  };
+                        : { 'CPANPLUS::Dist::Build' => '0.24'  };
                 },
                 sub { return 1 },   # always enabled
             ],            
             cpantest        => [
-                {
-                    LWP              => '0.0',
-                    'LWP::UserAgent' => '0.0',
-                    'HTTP::Request'  => '0.0',
-                    URI              => '0.0',
-                    YAML             => '0.0',
-                    'Test::Reporter' => 1.27,
+                { 'Test::Reporter'  => '1.34',
+                  'Parse::CPAN::Meta' => '0.0'
                 },
                 sub { 
                     my $cb = shift;
@@ -134,14 +133,20 @@ CPANPLUS::Selfupdate
             signature => [
                 sub {
                     my $cb      = shift;
-                    return if can_run('gpg');
-                        ### leave this out -- Crypt::OpenPGP is fairly
-                        ### painful to install, and broken on some platforms
-                        ### so we'll just always fall back to gpg. It may
-                        ### issue a warning or 2, but that's about it.
-                        ### this change due to this ticket: #26914
-                        # and $cb->configure_object->get_conf('prefer_bin');
-                    return { 'Crypt::OpenPGP' => '0.0' };
+                    return {
+                        'Module::Signature' => '0.06',
+                    } if can_run('gpg');
+                    ### leave this out -- Crypt::OpenPGP is fairly
+                    ### painful to install, and broken on some platforms
+                    ### so we'll just always fall back to gpg. It may
+                    ### issue a warning or 2, but that's about it.
+                    ### this change due to this ticket: #26914
+                    # and $cb->configure_object->get_conf('prefer_bin');
+
+                    return { 
+                        'Crypt::OpenPGP'    => '0.0', 
+                        'Module::Signature' => '0.06',
+                    };
                 },            
                 sub {
                     my $cb = shift;
@@ -155,6 +160,17 @@ CPANPLUS::Selfupdate
                     return $cb->configure_object->get_conf('storable');
                 },
             ],
+            sqlite_backend => [
+                {   'DBIx::Simple' => '0.0',
+                    'DBD::SQLite'  => '0.0',
+                },
+                sub {
+                    my $cb   = shift;
+                    my $conf = $cb->configure_object;
+                    return $conf->get_conf('source_engine') 
+                        eq 'CPANPLUS::Internals::Source::SQLite'
+                },                        
+            ],                    
         },
         core => {
             'CPANPLUS' => '0.0',
